@@ -21,28 +21,39 @@
 #ifndef __CFG_H__
 #define __CFG_H__
 
+enum state {STATE_OFF, STATE_ON, STATE_AUTO};
 enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMENT, MODE_END};
 
 /* configuration defaults */
-#define POLLTIME 1000
-#define NVRAMDEV "/dev/nvram"
-#define MIXERSTEPS 20
-#define MIXERDEV "/dev/mixer"
+#define DEFAULT_POLLTIME 1000
+#define DEFAULT_NVRAMDEV "/dev/nvram"
+#define DEFAULT_MIXERSTEPS 20
+#define DEFAULT_MIXERDEV "/dev/mixer"
 #ifdef HAVE_LIBXOSD
-#define OSDFONT "-*-lucidatypewriter-medium-r-normal-*-*-250-*-*-*-*-*-*"
-#define OSDCOLOR "BLUE"
-#define OSDTIMEOUT 3
-#define OSDOFFSET 25
-#define OSDPOS XOSD_bottom
+#define DEFAULT_OSDFONT "-*-lucidatypewriter-medium-r-normal-*-*-250-*-*-*-*-*-*"
+#define DEFAULT_OSDCOLOR "BLUE"
+#define DEFAULT_OSDTIMEOUT 3
+#define DEFAULT_OSDOFFSET 25
+#define DEFAULT_OSDPOS XOSD_bottom
+#define DEFAULT_OSDALIGN XOSD_left
 #endif /* HAVE_LIBXOSD */
 
-/* Global configuration file */
+/* configuration files */
 #define GLOBAL_CONFIG_FILE "/etc/tpbrc"
+#define PRIVATE_CONFIG_FILE ".tpbrc"
 
 /* Keywords in configuration file */
+#define CFG_POWERMGT "powermgt"
+#define CFG_POWERMGT_ON "on"
+#define CFG_POWERMGT_OFF "off"
+#define CFG_POWERMGT_AUTO "auto"
 #define CFG_NVRAM "nvram"
 #define CFG_POLLTIME "polltime"
 #define CFG_THINKPAD "thinkpad"
+#define CFG_HOME "home"
+#define CFG_SEARCH "search"
+#define CFG_MAIL "mail"
+#define CFG_CALLBACK "callback"
 #define CFG_MIXER "mixer"
 #define CFG_MIXER_ON "on"
 #define CFG_MIXER_OFF "off"
@@ -56,17 +67,26 @@ enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMEN
 #define CFG_OSDPOS "osdpos"
 #define CFG_OSDPOS_TOP "top"
 #define CFG_OSDPOS_BOTTOM "bottom"
+#define CFG_OSDALIGN "osdalign"
+#define CFG_OSDALIGN_LEFT "left"
+#define CFG_OSDALIGN_CENTER "center"
+#define CFG_OSDALIGN_RIGHT "right"
 #define CFG_OSD "osd"
 #define CFG_OSD_ON "on"
 #define CFG_OSD_OFF "off"
 #endif /* HAVE_LIBXOSD */
 
-#define BSIZE 256
+#define BUFFER_SIZE 256
 
 typedef struct {
+	int powermgt;
 	char *nvram;
 	int polltime;
 	char *tpbcmd;
+	char *homecmd;
+	char *searchcmd;
+	char *mailcmd;
+	char *callback;
 	int mixer;
 	int mixersteps;
 	char *mixerdev;
@@ -78,10 +98,11 @@ typedef struct {
 	int osdtimeout;
 	int osdoffset;
 	xosd_pos osdpos;
+	xosd_align osdalign;
 #endif /* HAVE_LIBXOSD */
 } config;
 
-int read_cfg_file(char *name);
+int parse_cfg_file(char *name);
 void init_cfg(void);
 void override_cfg(config *master);
 void set_value(char *key, char *arg, config *cfg);
