@@ -22,23 +22,30 @@
 #define __TPB_H__
 
 #define MAXVOLUME 100
+#define CALLBACKCMDLENGTH 256
 
 typedef struct {
-	char tpb; /* ThinkPad button */
-	char kt;  /* ThinkLight */
-	char ht;  /* hibernation/suspend toggle */
-	char ds;  /* display state */
-	char bl;  /* brightness level */
-	char bt;  /* brightness toggle */
-	char vl;  /* volume level */
-	char vt;  /* volume toggle */
-	char mt;  /* mute toggle */
-	char ac;  /* ac connected */
-	char pma; /* power management mode ac */
-	char pmb; /* power management mode battery */
-} t_tpb;
+	char thinkpad_toggle;   /* ThinkPad button */
+	char zoom_toggle;       /* zoom toggle */
+	char display_toggle;    /* display toggle */
+	char home_toggle;       /* Home button */
+	char search_toggle;     /* Search button */
+	char mail_toggle;       /* Mail button */
+	char thinklight_toggle; /* ThinkLight */
+	char hibernate_toggle;  /* hibernation/suspend toggle */
+	char display_state;     /* display state */
+	char expand_toggle;     /* hv expansion state */
+	char brightness_level;  /* brightness level */
+	char brightness_toggle; /* brightness toggle */
+	char volume_level;      /* volume level */
+	char volume_toggle;     /* volume toggle */
+	char mute_toggle;       /* mute toggle */
+	char ac_state;          /* ac connected */
+	char powermgt_ac;       /* power management mode ac */
+	char powermgt_battery;  /* power management mode battery */
+} t_nvram_state;
 
-int get_state(t_tpb *tpbs);
+int get_state(t_nvram_state *nvram_state);
 int fork_app(char *cmd);
 void set_vl(void);
 int set_mixer(int change);
